@@ -983,13 +983,14 @@ def predict_imspec(imspec, scene=False, atl=None):
         except:
             pass
 
-
     if atl is not None:
         try:
             at_list.append(renpy.display.motion.ATLTransform(atl))
         except:
             pass
 
+    layer = renpy.exports.default_layer(layer, tag or name, expression)
+
     if scene:
         renpy.game.context().images.predict_scene(layer)
 
@@ -1023,6 +1024,8 @@ def show_imspec(imspec, atl=None):
 
     at_list = [ renpy.python.py_eval(i) for i in at_list ]
 
+    layer = renpy.exports.default_layer(layer, tag or name, expression)
+
     renpy.config.show(name,
                       at_list=at_list,
                       layer=layer,
@@ -1197,6 +1200,8 @@ class Hide(Node):
         if tag is None:
             tag = name[0]
 
+        layer = renpy.exports.default_layer(layer, tag)
+
         renpy.game.context().images.predict_hide(tag, layer)
 
         return [ self.next ]
@@ -1216,6 +1221,8 @@ class Hide(Node):
         elif len(self.imspec) == 7:
             name, _expression, tag, _at_list, layer, _zorder, _behind = self.imspec
 
+        layer = renpy.exports.default_layer(layer, tag or name)
+
         renpy.config.hide(tag or name, layer)
 
 
